@@ -87,7 +87,7 @@ class OpenSSHGenerator(ConfigGenerator):
 
     sign_map = {
         'RSA-SHA1': 'ssh-rsa',
-        'DSA-SHA1': 'ssh-dss',
+        'DSA-SHA1': '',  # openssh no longer recognizes it
         'RSA-SHA2-256': 'rsa-sha2-256',
         'RSA-SHA2-512': 'rsa-sha2-512',
         'ECDSA-SHA2-256': 'ecdsa-sha2-nistp256',
@@ -100,7 +100,7 @@ class OpenSSHGenerator(ConfigGenerator):
 
     sign_map_certs = {
         'RSA-SHA1': 'ssh-rsa-cert-v01@openssh.com',
-        'DSA-SHA1': 'ssh-dss-cert-v01@openssh.com',
+        'DSA-SHA1': '',  # openssh no longer recognizes it
         'RSA-SHA2-256': 'rsa-sha2-256-cert-v01@openssh.com',
         'RSA-SHA2-512': 'rsa-sha2-512-cert-v01@openssh.com',
         'ECDSA-SHA2-256': 'ecdsa-sha2-nistp256-cert-v01@openssh.com',
@@ -219,10 +219,10 @@ class OpenSSHGenerator(ConfigGenerator):
 
 class OpenSSHClientGenerator(OpenSSHGenerator):
     CONFIG_NAME = 'openssh'
-    SCOPES = {'ssh', 'openssh', 'openssh-client'}
 
     @classmethod
-    def generate_config(cls, policy):
+    def generate_config(cls, unscoped_policy):
+        policy = unscoped_policy.scoped({'ssh', 'openssh', 'openssh-client'})
         local_kx_map = dict(cls.kx_map)
         local_gss_kx_map = dict(cls.gss_kx_map)
 
@@ -259,14 +259,14 @@ class OpenSSHClientGenerator(OpenSSHGenerator):
 
 class OpenSSHServerGenerator(OpenSSHGenerator):
     CONFIG_NAME = 'opensshserver'
-    SCOPES = {'ssh', 'openssh', 'openssh-server'}
 
     # We need to restart here,
     # since systemd needs to pick up new command line options
     RELOAD_CMD = 'systemctl try-restart sshd.service 2>/dev/null || :\n'
 
     @classmethod
-    def generate_config(cls, policy):
+    def generate_config(cls, unscoped_policy):
+        policy = unscoped_policy.scoped({'ssh', 'openssh', 'openssh-server'})
         return cls.generate_options(policy, cls.kx_map, cls.gss_kx_map,
                                     do_host_key=True)
 
